package com.jz.dm.mall.moduls.controller.customer;

import com.jz.common.base.BaseController;
import com.jz.common.constant.RedisMessageConstant;
import com.jz.common.constant.ResultCode;
import com.jz.common.constant.ResultMsg;
import com.jz.dm.mall.moduls.entity.MallCustomer;
import com.jz.common.utils.Result;
import com.jz.common.utils.StatusCode;
import com.jz.dm.mall.moduls.service.MallCustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.Map;

/**
 * 商城用户(MallCustomer)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:40
 */
@RestController
@RequestMapping("/mallCustomer")
public class MallCustomerController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private MallCustomerService mallCustomerService;

    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * 添加用户
     * @param paramMap
     * @return
     */
    @PostMapping("/saveCustomer")
    public Result saveCustomer(@RequestParam(required = false) Map<String, String> paramMap) {
        if (paramMap != null) {
            String username = paramMap.get("username");
            String telephone = paramMap.get("telephone");
            if (username == null) {
                return new Result(false, "请输入用户名！");
            }
//            // 根据用户名查询用户信息
////            MallCustomer mallCustomer = mallCustomerService.selectByAccount(username);
////            if (mallCustomer.getCustomerAccount().equals(username)) {
////                return new Result(false, "用户名相同！");
////            }
////            if (mallCustomer.getCustomerPhone().equals(telephone)) {
////                return new Result(false,"手机号相同！");
////            }
            mallCustomerService.saveCustomer(paramMap);
            return new Result(true, "注册成功！", StatusCode.OK);
        }
       return new Result(false, "注册失败！", StatusCode.ERROR);
    }

    /**
     * 手机号码校验
     * @param paramMap
     * @return
     */
    @PostMapping(value = "/check")
    public Result loginCheck(@RequestBody Map<String, String> paramMap) {
        // 获取手机号码
        String telephone = paramMap.get("telephone");
        String key = RedisMessageConstant.SENDTYPE_LOGIN + "_" + telephone;
        // 获取redis中key对应的值
        String codeInRedis = (String) redisTemplate.opsForValue().get(key);
        if (StringUtils.isEmpty(codeInRedis)) {
            return new Result(false, "请重新获取验证码!", StatusCode.ERROR);
        }
        // 判断验证码是否一致
        if (!codeInRedis.equals(paramMap.get("validateCode"))) {
            return new Result(false, "验证码不正确！", StatusCode.ERROR);
        }
        // 删除redis的验证码
        redisTemplate.delete(key);

        return new Result(true, "验证码正确！", StatusCode.OK);
    }


}